@@ -180,13 +180,12 @@ protomod_finalize(struct l7vs_service *srv, struct l7vs_conn *conn, char *buf, s
 		//check realserver
 		for( d = g_list_first( active_list ); d != NULL; d = g_list_next(d) ){
 			struct l7vs_dest* active_d = d->data;
-			if( memcmp( &(active_d->addr.sin_addr.s_addr ),
-				    &((*dest)->addr.sin_addr.s_addr ),
-				    sizeof( struct in_addr ) )
-			    && active_d->addr.sin_port == (*dest)->addr.sin_port ){
-			*dest = active_d;
-			ret = 0;
-			goto PROTOMOD_FINALIZE_OUT;
+			if( ( active_d->addr.sin_addr.s_addr == (*dest)->addr.sin_addr.s_addr ) 
+			    &&
+			    ( active_d->addr.sin_port == (*dest)->addr.sin_port )){
+				*dest = active_d;
+				ret = 0;
+				goto PROTOMOD_FINALIZE_OUT;
 			}
 		}
 		// check schedule
