@@ -95,5 +95,5 @@ l7vs_sched_lc_schedule(struct l7vs_service *srv,
 		}	
 	}
 	g_list_free( active_dest_list );
-	return target;
+	return rect;
 }
