@@ -106,7 +106,7 @@ l7vs_sched_rr_schedule(struct l7vs_service *srv, struct l7vs_conn *conn)
 	contenor = (struct servicedest_contenor*) srv->sched_data;
 	for( ptr = g_list_first( active_dest_list ); ptr ; ptr = g_list_next( ptr ) ){
 		struct l7vs_dest* dest = ptr->data;
-		if( memcmp( &(dest->addr.sin_addr), &(contenor->addr), sizeof( struct in_addr ) )
+		if( !memcmp( &(dest->addr.sin_addr), &(contenor->addr), sizeof( struct in_addr ) )
 		    &&
 		    dest->addr.sin_port == contenor->port ){
 		    ret = ptr->data;
@@ -118,7 +118,7 @@ l7vs_sched_rr_schedule(struct l7vs_service *srv, struct l7vs_conn *conn)
 		ret = ( struct l7vs_dest* ) ptr->data;
 		goto L7VS_SCHED_RR_SCHEDULE_END;
 	}
-	ptr = g_list_next( active_dest_list );
+	ptr = g_list_next( ptr );
 	if( !ptr ){
 		ptr = g_list_first( active_dest_list );
 		ret = ( struct l7vs_dest* ) ptr->data;
