@@ -115,7 +115,7 @@ struct l7vs_dest* l7vs_sched_wrr_schedule(struct l7vs_service *srv, struct l7vs_
   struct l7vs_dest *dest;
   GList* active_dest_list = NULL;
   GList* ptr;
-  GList *now;
+  GList *now = NULL;
 
 	if(srv == NULL || srv->handle >= MAX_VS || srv->dest_list == NULL || srv->dest_list->data == NULL)
 	{
@@ -125,9 +125,12 @@ struct l7vs_dest* l7vs_sched_wrr_schedule(struct l7vs_service *srv, struct l7vs_
 
 	//create active dest
 	for( ptr = g_list_first( srv->dest_list ); ptr; ptr = g_list_next(ptr) ){
-		active_dest_list = g_list_append( active_dest_list, ptr->data );
+		if( ((struct l7vs_dest*) ( ptr->data ))->weight > 0 ) active_dest_list = g_list_append( active_dest_list, ptr->data );
+	}
+	if( !active_dest_list ) {
+		dest = NULL;
+		goto OUT;
 	}
-	if( !active_dest_list ) goto OUT;
 
 	if (vs_initialized_flags[srv->handle] == VS_NOTINUSE) {
 
@@ -137,40 +140,35 @@ struct l7vs_dest* l7vs_sched_wrr_schedule(struct l7vs_service *srv, struct l7vs_
 		}
 
 		vs_weights[srv->handle]->currentWeight = vs_weights[srv->handle]->maxWeight;
-		struct servicedest_contenor* contenor = malloc( sizeof( struct servicedest_contenor ) );
-		struct l7vs_dest* tdest = ( struct l7vs_dest* ) g_list_first( active_dest_list );
-		contenor->handle = srv->handle;
-		contenor->addr = tdest->addr.sin_addr;//C90 stuct copy ok!
-		contenor->port = tdest->addr.sin_port;
-		servicedest_list = g_list_append( servicedest_list, contenor );
-		srv->sched_data = contenor;
 	} else {
 		if (l7vs_sched_wrr_recalc(srv) != 0) {
 			dest = NULL;
 			goto OUT;
 		}
-		if (srv->sched_data == NULL) {
-			struct servicedest_contenor* contenor = malloc( sizeof( struct servicedest_contenor ) );
-			struct l7vs_dest* tdest = ( struct l7vs_dest* ) g_list_first( active_dest_list );
-			contenor->handle = srv->handle;
-			contenor->addr = tdest->addr.sin_addr;
-			contenor->port = tdest->addr.sin_port;
-			servicedest_list = g_list_append( servicedest_list, contenor );
-			srv->sched_data = contenor;
-		}
 	}
 
-	for( ptr = g_list_first( active_dest_list ); ptr; ptr = g_list_next(ptr) ){
-		struct l7vs_dest* tdest = ptr->data;
-		struct servicedest_contenor* contenor = (struct servicedest_contenor*) srv->sched_data;
-		if( memcmp( &(tdest->addr.sin_addr), &(contenor->addr), sizeof( struct in_addr ) )
-		    &&
-		    tdest->addr.sin_port == contenor->port ){
-			now = (GList*) ptr;
-			break;
+	if (srv->sched_data) {
+		for( ptr = g_list_first( active_dest_list ); ptr; ptr = g_list_next(ptr) ){
+			struct l7vs_dest* tdest = ptr->data;
+			struct servicedest_contenor* contenor = (struct servicedest_contenor*) srv->sched_data;
+			if( !memcmp( &(tdest->addr.sin_addr), &(contenor->addr), sizeof( struct in_addr ) )
+			    &&
+			    tdest->addr.sin_port == contenor->port ){
+				now = (GList*) ptr;
+				break;
+			}
 		}
 	}
-//	now = (GList*)srv->sched_data;
+	if (now == NULL || srv->sched_data == NULL) {
+		struct servicedest_contenor* contenor = malloc( sizeof( struct servicedest_contenor ) );
+		now = g_list_first( active_dest_list );
+		struct l7vs_dest* tdest = ( struct l7vs_dest* ) now->data;
+		contenor->handle = srv->handle;
+		contenor->addr = tdest->addr.sin_addr;
+		contenor->port = tdest->addr.sin_port;
+		servicedest_list = g_list_append( servicedest_list, contenor );
+		srv->sched_data = contenor;
+	}
 
 	while (1)
 	{
@@ -201,6 +199,11 @@ struct l7vs_dest* l7vs_sched_wrr_schedule(struct l7vs_service *srv, struct l7vs_
 			now = g_list_next(now);
 			if (now == NULL) {
 				now = g_list_first(srv->dest_list);
+				vs_weights[srv->handle]->currentWeight -= vs_weights[srv->handle]->gcd;
+
+				if (vs_weights[srv->handle]->currentWeight <= 0) {
+					vs_weights[srv->handle]->currentWeight = vs_weights[srv->handle]->maxWeight;
+				}
 			}
 		}
 	}
@@ -305,7 +308,7 @@ static int l7vs_sched_wrr_getMaxWeight(struct l7vs_service *srv)
 static int l7vs_sched_wrr_gcd(int a, int b)
 {
 
-  if (a == b) {
+  if (a == b || b == 0) {
     return a;
 
   }
